export declare type MainFunction<T> = (...args: any[]) => Promise<T> | T;
export declare type HookFunction = (tries?: number, reason?: any) => Promise<any> | any;
export interface ExecutorOptions {
    maxTries?: number;
    timeout?: number;
    waiter?: HookFunction;
    retryCondition?: HookFunction;
    beforeTry?: HookFunction;
    afterTry?: HookFunction;
    beforeWait?: HookFunction;
    afterWait?: HookFunction;
    doFinally?: HookFunction;
}
export interface ExecutorInterface<T> {
    execute(): Promise<T>;
}
export declare class Executor<T> implements ExecutorInterface<T> {
    protected main: MainFunction<T>;
    protected options?: ExecutorOptions | undefined;
    protected static defaultMaxTries: number;
    protected static defaultTimeout: number;
    protected static defaultRetryCondition: HookFunction;
    protected static defaultWaiter: HookFunction;
    protected maxTries: number;
    protected timeout: number;
    protected retryCondition: HookFunction;
    protected waiter: HookFunction;
    protected args: any[];
    protected beforeTry?: HookFunction;
    protected afterTry?: HookFunction;
    protected beforeWait?: HookFunction;
    protected afterWait?: HookFunction;
    protected doFinally?: HookFunction;
    constructor(main: MainFunction<T>, options?: ExecutorOptions | undefined, ...args: any[]);
    execute(): Promise<T>;
    protected tryLoop(): Promise<T>;
    protected timer(duration: number): Promise<void>;
}
export default Executor;
